=======
History
=======

0.1.0 (2017-07-12)
------------------

* First release on PyPI.

0.1.1 (2017-07-25)
~~~~~~~~~~~~~~~~~

* Pre-release
* Bug fixes on calling local-best
* Implemented Local Best PSO

0.1.2 (2017-08-02)
~~~~~~~~~~~~~~~~~

* Pre-release
* Implemented Binary PSO
* More efficient API for gbest and lbest
* Documentation and tests

0.1.4 (2017-08-03)
~~~~~~~~~~~~~~~~~

* Well, this is embarassing...
* Added a patch to fix :code:`pip` installation